@@ -5,12 +5,14 @@ Custom input handlers for Parameters
 """
 
 from abc import ABC, abstractmethod
-from typing import Any
+from typing import Any, Callable
 
-__all__ = ['Input']
+__all__ = ['InputType']
+
+TypeFunc = Callable[[str], Any]
 
 
-class Input(ABC):
+class InputType(ABC):
     @abstractmethod
     def __call__(self, value: str) -> Any:
         """Process the parsed argument and convert it to the desired type"""
